@@ -26,5 +26,5 @@
 
 
 def take_care_of_my_tests():
-    from unclebob import bourbon
-    bourbon.taste()
+    from unclebob import monkey
+    monkey.patch()
